==> zanata-common-api-2.3.0.jar: org/zanata/rest/dto/extensions/ExtensionType.java <==
/*
 * Copyright 2010, Red Hat, Inc. and individual contributors as indicated by the
 * @author tags. See the copyright.txt file in the distribution for a full
 * listing of individual contributors.
 * 
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.zanata.rest.dto.extensions;

import java.util.HashSet;
import java.util.Set;

/**
 * @author Carlos Munoz <a href="mailto:camunoz@redhat.com">camunoz@redhat.com</a>
 */
public enum ExtensionType
{
   GetText
   {
      @Override
      public String toString()
      {
         return "gettext";
      }
   },
   Comment
   {
      @Override
      public String toString()
      {
         return "comment";
      }
   };

   public static Set<String> asStringSet()
   {
      Set<String> values = new HashSet<String>(values().length);
      for( ExtensionType et : values() )
      {
         values.add(et.toString());
      }
      return values;
   }
}

==> zanata-common-api-3.9.1.jar: org/zanata/rest/dto/extensions/ExtensionType.java <==
/*
 * Copyright 2010, Red Hat, Inc. and individual contributors as indicated by the
 * @author tags. See the copyright.txt file in the distribution for a full
 * listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.zanata.rest.dto.extensions;

import java.util.HashSet;
import java.util.Set;

/**
 * @author Carlos Munoz <a
 *         href="mailto:camunoz@redhat.com">camunoz@redhat.com</a>
 */
public enum ExtensionType {
    GetText {
        @Override
        public String toString() {
            return "gettext";
        }
    },
    Comment {
        @Override
        public String toString() {
            return "comment";
        }
    };

    public static Set<String> asStringSet() {
        Set<String> values = new HashSet<String>(values().length);
        for (ExtensionType et : values()) {
            values.add(et.toString());
        }
        return values;
    }
}
